@@ -19,7 +19,6 @@
 #  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #  SOFTWARE.
 
-
 import os
 import sys
 import time
@@ -38,9 +37,10 @@ from libs import bflb_security
 from libs import bflb_img_create
 from libs import bflb_interface_uart
 from libs import bflb_interface_sdio
+import config as gol
 
 try:
-    from globalvar import mutex, GlobalVar
+    from config import mutex
     th_sign = True
 except ImportError:
     th_sign = False
@@ -88,11 +88,21 @@ class BflbImgLoader(object):
                 "data_len": "0160",
                 "callback": None
             },
+            "628_load_boot_header": {
+                "cmd_id": "11",
+                "data_len": "0100",
+                "callback": None
+            },
             "616_load_boot_header": {
                 "cmd_id": "11",
                 "data_len": "0100",
                 "callback": None
             },
+            "702l_load_boot_header": {
+                "cmd_id": "11",
+                "data_len": "00F0",
+                "callback": None
+            },
             "load_publick_key": {
                 "cmd_id": "12",
                 "data_len": "0044",
@@ -202,10 +212,18 @@ class BflbImgLoader(object):
                 tmp = bflb_utils.bytearray_reverse(read_data[140:144])
                 self._segcnt = bflb_utils.bytearray_to_int(tmp)
                 bflb_utils.printf("segcnt is ", self._segcnt)
+            elif section == "628_load_boot_header":
+                tmp = bflb_utils.bytearray_reverse(read_data[136:140])
+                self._segcnt = bflb_utils.bytearray_to_int(tmp)
+                bflb_utils.printf("segcnt is ", self._segcnt)
             elif section == "616_load_boot_header":
                 tmp = bflb_utils.bytearray_reverse(read_data[132:136])
                 self._segcnt = bflb_utils.bytearray_to_int(tmp)
                 bflb_utils.printf("segcnt is ", self._segcnt)
+            elif section == "702l_load_boot_header":
+                tmp = bflb_utils.bytearray_reverse(read_data[120:124])
+                self._segcnt = bflb_utils.bytearray_to_int(tmp)
+                bflb_utils.printf("segcnt is ", self._segcnt)
             if section == "load_signature" or section == "load_signature2":
                 tmp = bflb_utils.bytearray_reverse(read_data[0:4])
                 sig_len = bflb_utils.bytearray_to_int(tmp)
@@ -286,7 +304,9 @@ class BflbImgLoader(object):
         self._bootrom_cmds.get("get_boot_info")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_boot_header")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("808_load_boot_header")["callback"] = self.boot_process_load_cmd
+        self._bootrom_cmds.get("628_load_boot_header")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("616_load_boot_header")["callback"] = self.boot_process_load_cmd
+        self._bootrom_cmds.get("702l_load_boot_header")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_publick_key")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_publick_key2")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_signature")["callback"] = self.boot_process_load_cmd
@@ -356,7 +376,7 @@ class BflbImgLoader(object):
                             reset_revert=True,
                             cutoff_time=0,
                             shake_hand_retry=2,
-                            iap_timeout=0,
+                            isp_timeout=0,
                             boot_load=True):
         self.bflb_boot_if.if_init(comnum, sh_baudrate, self._chip_type, self._chip_name)
 
@@ -364,7 +384,7 @@ class BflbImgLoader(object):
         if self._chip_type == "wb03":
             self.bflb_boot_if.if_toggle_boot(do_reset, reset_hold_time, shake_hand_delay,
                                              reset_revert, cutoff_time, shake_hand_retry,
-                                             iap_timeout, boot_load)
+                                             isp_timeout, boot_load)
             bflb_utils.printf("get_chip_id")
             # get chip id before download
             ret, data_read = self.boot_process_one_section("get_chip_id", 0)
@@ -382,7 +402,7 @@ class BflbImgLoader(object):
                 self.bflb_boot_if.if_set_602a0_download_fix(False)
             ret = self.bflb_boot_if.if_shakehand(do_reset, reset_hold_time, shake_hand_delay,
                                                  reset_revert, cutoff_time, shake_hand_retry,
-                                                 iap_timeout, boot_load)
+                                                 isp_timeout, boot_load)
             if self._chip_type == "bl602":
                 self.bflb_boot_if.if_set_602a0_download_fix(False)
             if ret != "OK":
@@ -399,7 +419,6 @@ class BflbImgLoader(object):
         bflb_utils.printf("shake hand success")
         return ret
 
-
     ########################main process###############################################
     def img_load_main_process(self, file, group, createcfg, callback=None, record_bootinfo=None):
         encrypt_blk_size = 16
@@ -415,33 +434,26 @@ class BflbImgLoader(object):
         data_read = binascii.hexlify(data_read)
         bflb_utils.printf("data read is ", data_read)
         bootinfo = data_read.decode("utf-8")
-        if self._chip_type == "bl702":
+        chipid = None
+        if self._chip_type == "bl702" or self._chip_type == "bl702l":
             chipid = bootinfo[32:34] + bootinfo[34:36] + bootinfo[36:38] + \
                 bootinfo[38:40] + bootinfo[40:42] + bootinfo[42:44] + bootinfo[44:46] + bootinfo[46:48]
-            bflb_utils.printf(
-                "========= ChipID: ", bootinfo[32:34] + bootinfo[34:36] + bootinfo[36:38] + 
-                bootinfo[38:40] + bootinfo[40:42] + bootinfo[42:44] + bootinfo[44:46] + bootinfo[46:48], " =========")
         else:
             chipid = bootinfo[34:36] + bootinfo[32:34] + bootinfo[30:32] + \
                 bootinfo[28:30] + bootinfo[26:28] + bootinfo[24:26]
-            bflb_utils.printf(
-                "========= ChipID: ", bootinfo[34:36] + bootinfo[32:34] + bootinfo[30:32] +
-                bootinfo[28:30] + bootinfo[26:28] + bootinfo[24:26], " =========")
+        bflb_utils.printf("========= ChipID: ", chipid, " =========")
         if qt_sign and th_sign and QtCore.QThread.currentThread().objectName():
             with mutex:
                 num = str(QtCore.QThread.currentThread().objectName())
-                # print("=========" + str(GlobalVar.list_download_last) + "=========")
-                for i, j in GlobalVar.list_download_last:
-                    if chipid == i and j is True:
+                gol.list_chipid[int(num) - 1] = chipid
+                if chipid is not None:
+                    gol.list_chipid_check[int(num) - 1] = chipid
+                for i, j in gol.list_download_check_last:
+                    if (chipid is not None) and (chipid == i) and (j is True):
                         return "repeat_burn", bootinfo
-                GlobalVar.list_chipid[int(num)-1] = chipid
-#                 if chipid in GlobalVar.list_chipid and GlobalVar.list_result_last[int(num)-1] is True:
-#                     return "repeat_burn", bootinfo
-#                 else:
-#                     GlobalVar.list_chipid[int(num)-1] = chipid           
         # bflb_utils.printf(int(data_read[10:12], 16))
         bflb_utils.printf("last boot info: ", record_bootinfo)
-        if record_bootinfo!=None and bootinfo[8:] == record_bootinfo[8:]:
+        if record_bootinfo != None and bootinfo[8:] == record_bootinfo[8:]:
             bflb_utils.printf("repeated chip")
             return "repeat_burn", bootinfo
         if bootinfo[:8] == "FFFFFFFF" or bootinfo[:8] == "ffffffff":
@@ -452,10 +464,12 @@ class BflbImgLoader(object):
         if self._chip_type == "bl60x":
             sign = int(data_read[8:10], 16) & 0x03
             encrypt = (int(data_read[8:10], 16) & 0x0c) >> 2
-        elif self._chip_type == "bl602" or self._chip_type == "bl702":
+        elif self._chip_type == "bl602" \
+          or self._chip_type == "bl702" \
+          or self._chip_type == "bl702l":
             sign = int(data_read[8:10], 16)
             encrypt = int(data_read[10:12], 16)
-        elif self._chip_type == "bl808":
+        elif self._chip_type == "bl808" or self._chip_type == "bl628":
             if group == 0:
                 sign = int(data_read[8:10], 16)
                 encrypt = int(data_read[12:14], 16)
@@ -469,8 +483,8 @@ class BflbImgLoader(object):
 
         # encrypt eflash loader helper bin
         if createcfg != None and createcfg != "":
-            ret, encrypted_data = bflb_img_create.encrypt_loader_bin(self._chip_type,
-                file, sign, encrypt, createcfg)
+            ret, encrypted_data = bflb_img_create.encrypt_loader_bin(self._chip_type, file, sign,
+                                                                     encrypt, createcfg)
             if ret == True:
                 # create new eflash loader helper bin
                 filename, ext = os.path.splitext(file)
@@ -480,15 +494,24 @@ class BflbImgLoader(object):
                 fp.close()
                 self._imge_fp = open(file_encrypt, 'rb')
             else:
+                file = os.path.join(bflb_utils.app_path, file)
                 self._imge_fp = open(file, 'rb')
         else:
+            file = os.path.join(bflb_utils.app_path, file)
             self._imge_fp = open(file, 'rb')
+        if self._chip_type == "wb03":
+            # wb03 img loader, read 0xD0 len for cut wb03 header
+            self._imge_fp.read(0xD0)
 
         # start to process load flow
         if self._chip_type == "bl808":
             ret, dmy = self.boot_process_one_section("808_load_boot_header", 0)
+        elif self._chip_type == "bl628":
+            ret, dmy = self.boot_process_one_section("628_load_boot_header", 0)
         elif self._chip_type == "bl616" or self._chip_type == "wb03":
             ret, dmy = self.boot_process_one_section("616_load_boot_header", 0)
+        elif self._chip_type == "bl702l":
+            ret, dmy = self.boot_process_one_section("702l_load_boot_header", 0)
         else:
             ret, dmy = self.boot_process_one_section("load_boot_header", 0)
         if ret.startswith("OK") is False:
@@ -497,14 +520,16 @@ class BflbImgLoader(object):
             ret, dmy = self.boot_process_one_section("load_publick_key", 0)
             if ret.startswith("OK") is False:
                 return ret, bootinfo
-            if self._chip_type == "bl60x" or self._chip_type == "bl808":
+            if self._chip_type == "bl60x" or self._chip_type == "bl808" or \
+               self._chip_type == "bl628":
                 ret, dmy = self.boot_process_one_section("load_publick_key2", 0)
                 if ret.startswith("OK") is False:
                     return ret, bootinfo
             ret, dmy = self.boot_process_one_section("load_signature", 0)
             if ret.startswith("OK") is False:
                 return ret, bootinfo
-            if self._chip_type == "bl60x" or self._chip_type == "bl808":
+            if self._chip_type == "bl60x" or self._chip_type == "bl808" or \
+               self._chip_type == "bl628":
                 ret, dmy = self.boot_process_one_section("load_signature2", 0)
                 if ret.startswith("OK") is False:
                     return ret, bootinfo
@@ -595,21 +620,21 @@ class BflbImgLoader(object):
                          reset_revert=True,
                          cutoff_time=0,
                          shake_hand_retry=2,
-                         iap_timeout=0,
+                         isp_timeout=0,
                          boot_load=True):
         bflb_utils.printf("========= image get bootinfo =========")
         ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time,
                                        shake_hand_delay, reset_revert, cutoff_time,
-                                       shake_hand_retry, iap_timeout, boot_load)
+                                       shake_hand_retry, isp_timeout, boot_load)
         if ret == "shake hand fail" or ret == "change rate fail":
             bflb_utils.printf("shake hand fail")
             self.bflb_boot_if.if_close()
-            return False
+            return False, ""
         time.sleep(0.5)
         ret, data_read = self.boot_process_one_section("get_boot_info", 0)
         if ret.startswith("OK") is False:
             bflb_utils.printf("get_boot_info no ok")
-            return ret
+            return ret, ""
         # check with image file
         data_read = binascii.hexlify(data_read)
         bflb_utils.printf("data read is ", data_read)
@@ -636,23 +661,24 @@ class BflbImgLoader(object):
                          reset_revert=True,
                          cutoff_time=0,
                          shake_hand_retry=2,
-                         iap_timeout=0,
+                         isp_timeout=0,
                          boot_load=True,
                          record_bootinfo=None):
         bflb_utils.printf("========= image load =========")
         success = True
         bootinfo = None
         try:
-            ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time,
-                                        shake_hand_delay, reset_revert, cutoff_time,
-                                        shake_hand_retry, iap_timeout, boot_load)
+            ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset,
+                                           reset_hold_time, shake_hand_delay, reset_revert,
+                                           cutoff_time, shake_hand_retry, isp_timeout, boot_load)
             if ret == "shake hand fail" or ret == "change rate fail":
                 bflb_utils.printf("shake hand fail")
                 self.bflb_boot_if.if_close()
                 return False, bootinfo, ret
             time.sleep(0.01)
             if file1 is not None and file1 != "":
-                res, bootinfo = self.img_load_main_process(file1, 0, self._create_cfg, callback, record_bootinfo)
+                res, bootinfo = self.img_load_main_process(file1, 0, self._create_cfg, callback,
+                                                           record_bootinfo)
                 if res.startswith("OK") is False:
                     if res.startswith("repeat_burn") is True:
                         return False, bootinfo, res
@@ -662,7 +688,8 @@ class BflbImgLoader(object):
                             bflb_utils.printf("shakehand with eflash loader found")
                         return False, bootinfo, res
             if file2 is not None and file2 != "":
-                res, bootinfo = self.img_load_main_process(file2, 1, self._create_cfg, callback, record_bootinfo)
+                res, bootinfo = self.img_load_main_process(file2, 1, self._create_cfg, callback,
+                                                           record_bootinfo)
                 if res.startswith("OK") is False:
                     if res.startswith("repeat_burn") is True:
                         return False, bootinfo, res
